@@ -628,6 +628,8 @@ Tetris::fillMenu(GtkWidget *menu, char *pixname, char *dirname,
 	
 	if (addnone)
 	{
+        /* Translators: This is the placeholder item in the theme combo box
+           (preferences dialog) when no themes are available */
 		s = g_strdup(_("<none>"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (menu), _("<none>"));
 		*listp = g_list_append (*listp, s);
@@ -1395,7 +1397,7 @@ Tetris::gameAbout(GtkAction *action, void *d)
 #endif
 			       "version", VERSION,
 			       "comments", _("A classic game of fitting falling blocks together.\n\nGnometris is a part of GNOME Games."),
-			       "copyright", "Copyright \xc2\xa9 1999-2007 J. Marcin Gorycki",
+			       "copyright", "Copyright \xc2\xa9 1999-2008 J. Marcin Gorycki",
 			       "license", license,
 		               "website-label", _("GNOME Games web site"),
 			       "authors", authors,
